import unittest
from datetime import datetime, timezone
from jgtcommon import valid_datetime

class TestValidDatetime(unittest.TestCase):
    def test_valid_datetime(self):
        
        ##date_format = '%m.%d.%Y %H:%M:%S'
        
        # Test case 1: Valid datetime in the correct format
        str_datetime = "01.13.2022 12:00:00"
        result = valid_datetime(True)(str_datetime)
        expected_result = datetime(2022, 1, 13, 12, 0, 0, tzinfo=timezone.utc)
        self.assertEqual(result, expected_result)
        
        
        str_datetime = "01.13.2022 15:00:00"
        result = valid_datetime(True)(str_datetime)
        expected_result = datetime(2022, 1, 13, 15, 0, 0, tzinfo=timezone.utc)
        self.assertEqual(result, expected_result)



if __name__ == '__main__':
    unittest.main()


import os

import sys

sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))

import jgtcommon

def parse_args(exclude_env_alias=True):
    parser = jgtcommon.new_parser("Instrument/Timeframe Test Load from env","Test loading i/t from env",enable_specified_settings=True)
    #parser=jgtcommon.add_settings_argument(parser)
    #parser=jgtcommon._preload_settings_from_args(parser)
    
    parser= jgtcommon.add_instrument_timeframe_arguments(parser,from_jgt_env=True,exclude_env_alias=exclude_env_alias)
    parser=jgtcommon.add_demo_flag_argument(parser,from_jgt_env=True)
    args = jgtcommon.parse_args(parser)
    return args

def main():
    args = parse_args()
    print_arguments(args)

def print_arguments(args):
    print(args.instrument)
    print(args.timeframe)
    print("Using Demo" if args.demo else "Using real")
      
def main_alias():
    args = parse_args(False)
    print_arguments(args)
      
if __name__ == '__main__':
    main()
    



import os

import sys

sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))

import jgtcommon

def parse_args(exclude_env_alias=True):
    parser = jgtcommon.new_parser("Timeframe Test Load from env","Test loading timeframe from env",enable_specified_settings=True)
    
    
    parser= jgtcommon.add_timeframe_standalone_argument(parser,from_jgt_env=True,required=True,exclude_env_alias=exclude_env_alias)
    args = jgtcommon.parse_args(parser)
    return args

def main():
    args = parse_args()
    
    print(args.timeframe)
    
def main_alias():
    args = parse_args(False)
    
    print(args.timeframe)
       
if __name__ == '__main__':
    main()
    
